import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)
import java.util.*;

/**
 * Die (Ober-)Klasse für alle GraphicsAndGames-Welten
 * 
 * @author Albert Wiedemann
 * @version 1.0
 */
public class GrafikWelt extends World
{
    /** Interface für die Aktionsausführung. */
    interface AktionsEmpfaenger
    {
        /** Methode wird vom Taktgeber aufgerufen. */
        void Ausführen();
        void Taste (char taste);
        void SonderTaste (int taste);
        void Geklickt (int x, int y, int anzahl);
    }

    /** Das Zeichenfenster im Hintergrund */
    Zeichenfenster fenster;
    /** Feld aller zu zeichnenden Objekte. */
    private ArrayList<AktionsEmpfaenger> aktionsEmpfänger;
    /** Die (einzige) Instanz der Welt */
    static GrafikWelt dieWelt;

    /**
     * Legt die Welt und das Zeichenbild an.
     * 
     */
    public GrafikWelt()
    {    
        super(800, 600, 1); 
        fenster = new Zeichenfenster(800, 600, this);
        dieWelt = this; 
        aktionsEmpfänger = new ArrayList<AktionsEmpfaenger>();
    }
    
    /**
     * Trägt einen neuen Aktionsempfänger ein.
     * @param neu der neue Aktionsempfänger
     */
    void AktionsEmpfängerEintragen(AktionsEmpfaenger neu)
    {
       aktionsEmpfänger.add(neu);
    }
    
    /**
     * Löscht einen Aktionsempfänger aus der Liste.
     * @param alt der zu löschende Aktionsempfänger
     */
    void AktionsEmpfängerEntfernen(AktionsEmpfaenger alt)
    {
        aktionsEmpfänger.remove(alt);
    }
       
    /**
     * Hier werden die Ereignisse an *alle* Listener weiter geleitet.
     */
    @Override public void act() 
    {
        MouseInfo mi = Greenfoot.getMouseInfo();
        if (Greenfoot.mouseClicked(null) && (mi != null))
        {
            ArrayList<AktionsEmpfaenger> em = new ArrayList<AktionsEmpfaenger>(aktionsEmpfänger);
            for (AktionsEmpfaenger empfänger: em)
            {
                empfänger.Geklickt(mi.getX(), mi.getY(), mi.getClickCount());
            }
        }
        String key = Greenfoot.getKey();
        if (key != null)
        {
            if (key.length() == 1)
            {
                char c = key.charAt(0);
                if (Greenfoot.isKeyDown("shift") && ('a' <= c) && (c <= 'z'))
                {
                    c -= 32;
                }
                ArrayList<AktionsEmpfaenger> em = new ArrayList<AktionsEmpfaenger>(aktionsEmpfänger);
                for (AktionsEmpfaenger empfänger: em)
                {
                    empfänger.Taste(c);
                }
            }
            else  if (key.equals("space"))
            {
                ArrayList<AktionsEmpfaenger> em = new ArrayList<AktionsEmpfaenger>(aktionsEmpfänger);
                for (AktionsEmpfaenger empfänger: em)
                {
                    empfänger.Taste(' ');
                }
            }
            else
            {
                int k = 0;
                switch (key)
                {
                    case "up":
                        k = java.awt.event.KeyEvent.VK_UP;
                        break;
                    case "down":
                        k = java.awt.event.KeyEvent.VK_DOWN;
                        break;
                    case "left":
                        k = java.awt.event.KeyEvent.VK_LEFT;
                        break;
                    case "right":
                        k = java.awt.event.KeyEvent.VK_RIGHT;
                        break;
                    default:
                        break;
                }
                if (k != 0)
                {
                    ArrayList<AktionsEmpfaenger> em = new ArrayList<AktionsEmpfaenger>(aktionsEmpfänger);
                    for (AktionsEmpfaenger empfänger: em)
                    {
                        empfänger.SonderTaste(k);
                    }
                }
            }
        }
        ArrayList<AktionsEmpfaenger> em = new ArrayList<AktionsEmpfaenger>(aktionsEmpfänger);
        for (AktionsEmpfaenger empfänger: em)
        {
            empfänger.Ausführen();
        }
    }    
}
