import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)

/**
 * Zugriff auf die Ereignisse einschließlich Taktgeber.
 * 
 * @author Albert Wiedemann
 * @version 1.0
 */
public class Ereignisbehandlung extends Actor
{
    /** Referenz auf die eigene Welt. */
    protected GrafikWelt welt;
    /** Referenz auf eigene Bild. */
    protected GreenfootImage img;
    /** Referenz auf das Aktionsempfängerobjekt. */
    GrafikWelt.AktionsEmpfaenger aktionsEmpfänger;

    /**
     * Der Konstruktor meldet den Taktgeber
     * und die Eventlistener bei der Zeichenfläche an.
     */
    Ereignisbehandlung ()
    {
        img = new GreenfootImage(10, 10);
        img.setColor(new Color(255, 255, 255, 255));
        img.fill();
        setImage(img);
        welt = GrafikWelt.dieWelt;
        aktionsEmpfänger = new GrafikWelt.AktionsEmpfaenger()
        {
            public void Ausführen ()
            {
                TaktImpulsAusführen();
            }
            
            public void Taste (char taste)
            {
                TasteGedrückt(taste);
            }
            
            public void SonderTaste (int taste)
            {
                SonderTasteGedrückt(taste);
            }
            
            public void Geklickt (int x, int y, int anzahl)
            {
                MausGeklickt(x, y, anzahl);
            }
        };
        welt.AktionsEmpfängerEintragen(aktionsEmpfänger);
    }
    
    /**
     * Die eigentliche Aktionsmethode des Zeitgebers.
     * <br>Muss bei Bedarf von einer Unterklasse überschrieben werden. 
     */
    void TaktImpulsAusführen ()
    {
        System.out.println ("Tick");
    }

    /**
     * Zeitgeber starten.
     */
    void Starten ()
    {
        Greenfoot.start();
    }

    /**
     * Zeitgeber anhalten.
     */
    void Anhalten ()
    {
        Greenfoot.stop();
    }
    
    /**
     * Ablaufgeschwindigkeit des Zeitgebers einstellen.
     * 
     * @param dauer: Angabe in Millisekunden
     */
    void TaktdauerSetzen (int dauer)
    {
        Greenfoot.setSpeed(dauer <= 100 ? 100 : dauer >= 1500 ? 1 : ((-25 * dauer) / 100 + 375) / 10);
    }
    
    /**
     * Die eigentliche Aktionsmethode für gedrückte Tasten.
     * <br>Muss bei Bedarf von einer Unterklasse überschrieben werden. 
     * @param taste die gedrückte Taste
     */
    void TasteGedrückt (char taste)
    {
        System. out. println ("Taste: " + taste);
    }
    
    /**
     * Die eigentliche Aktionsmethode für gedrückte Sondertasten.
     * <br>Muss bei Bedarf von einer Unterklasse überschrieben werden. 
     * @param taste KeyCode der gedrückten Taste
     */
    void SonderTasteGedrückt (int taste)
    {
        System. out. println ("Sondertaste: " + taste);
    }
    
    /**
     * Die eigentliche Aktionsmethode für einen Mausklick.
     * <br>Muss bei Bedarf von einer Unterklasse überschrieben werden. 
     * @param x x-Position des Mausklicks
     * @param y y-Position des Mausklicks
     * @param anzahl Anzahl der aufeinanderfolgenden Mausklicks
     */
    void MausGeklickt (int x, int y, int anzahl)
    {
        System. out. println ("Maus: (" + x + "|" + y + "), " + anzahl + " mal");
    }
}
