/**
 * Spielfigur Dorian
 *
 * @author Johannes Neumeyer
 * @version 1.0
 */
class Dorian extends Figur
{
    private boolean stop;
    private boolean sprung;
    private int sprungzähler;
    private int teilsprungzähler;

    /**
     * Standardkonstruktor
     */
    public Dorian()
    {
        super();
        stop = false;
        sprung = false;
        FigurFestlegen();
        PositionSetzen(50, 100);
    }

    /**
     * Leitet das Springen von Dorian ein.
     * @param taste die gedrückte Taste
     */
    @Override void TasteGedrückt (char taste)
    {
        switch (taste)
        {
            case ' ':
            if (!sprung)
            {
                sprungzähler = 12;
                teilsprungzähler = 5;
                sprung = true;
            }
            break;
        }
    }

    /**
     * Steuert die Links- und Rechtsbewegung von Dorian.
     * @param taste die gedrückte Sondertaste
     */
    @Override void SonderTasteGedrückt (int taste)
    {
        if (!stop)
        {            
            switch (taste)
            {
                // Pfeil rechts
                case 39:

                if (!Berührt("schwarz"))
                {
                    PositionSetzen(XPositionGeben() + 4, YPositionGeben());
                }
                break;

                // Pfeil links
                case 37:

                if (!Berührt("weiß"))
                {
                    PositionSetzen(XPositionGeben() - 4, YPositionGeben());
                }
                break;
            }
        }
    }

    /**
     * Steuert das Springen und Fallen von Dorian.
     */
    @Override void AktionAusführen()
    {
        // nach oben Springen
        if (sprungzähler > 0)
        {
            Teilsprung();
        }

        // Fallen
        if (!(Berührt("hellgrün")) && YPositionGeben() < 600 && sprungzähler == 0)
        {
            // Fallen nach dem Absprung
            if (sprung)
            {
                PositionSetzen(XPositionGeben(), YPositionGeben() + 1);
                if (!Berührt("hellgrün") && YPositionGeben() < 600)
                {
                    PositionSetzen(XPositionGeben(), YPositionGeben() + 1);
                }

            }
            // Fallen ohne vorangegangenen Absprung (senkrecht nach unten fallen)
            else
            {
                while (!Berührt("hellgrün") && YPositionGeben() < 600 && sprungzähler == 0)
                {
                    PositionSetzen(XPositionGeben(), YPositionGeben() + 1);
                }
            }

            if (Berührt("hellgrün"))
            {
                sprung = false;
            }
        }
    }

    /**
     * Prüft, ob Dorian beim Springen anstößt,
     * und führt ansonsten die Sprungroutine weiter.
     */
    public void Teilsprung()
    {
        if (teilsprungzähler <= 0)
        {
            // Wenn Dorian mit dem Kopf an einem DLRechteck anstößt
            if (Berührt("hellgelb"))
            {
                sprungzähler = 0;
                teilsprungzähler = 0;
            }
            else
            {
                PositionSetzen(XPositionGeben(), YPositionGeben() - 5);
                sprungzähler = sprungzähler - 1;
                teilsprungzähler = 5;
            }
        }
        else
        {
            teilsprungzähler = teilsprungzähler - 1;
        }
    }

    /**
     * Stoppt das Spiel, z. B. wenn Dorian das Ziel eines Levels erreicht hat
     */
    public void Stoppen()
    {
        stop = true;
    }

    /**
     * Legt das Aussehen von Dorian fest.
     */
    private void FigurFestlegen()
    {
        GrößeSetzen(50);

        // Haare
        FigurteilFestlegenRechteck(-32, -50, 30, 6, "rot");
        FigurteilFestlegenRechteck(-38, -44, 48, 6, "rot");
 
        // Gesicht
        FigurteilFestlegenRechteck(-20, -38, 24, 6, "orange");
        FigurteilFestlegenRechteck(-38, -32, 48, 18, "orange");
        FigurteilFestlegenRechteck(-32, -14, 40, 6, "orange");
        FigurteilFestlegenRechteck(10, -26, 6, 6, "orange");
 
        FigurteilFestlegenRechteck(-38, -38, 18, 6, "rot");
        FigurteilFestlegenRechteck(-44, -32, 6, 18, "rot");
        FigurteilFestlegenRechteck(-32, -32, 6, 12, "rot");
        FigurteilFestlegenRechteck(-38, -20, 6, 6, "rot");
        FigurteilFestlegenRechteck(-26, -26, 6, 6, "rot");
 
        FigurteilFestlegenRechteck(-8, -38, 6, 12, "schwarz");
        FigurteilFestlegenRechteck(-8, -20, 18, 6, "schwarz");
 
        // blaues Hemd
        FigurteilFestlegenRechteck(-38, -8, 48, 6, "blau");   
        FigurteilFestlegenRechteck(-44, -2, 60, 6, "blau");           
        FigurteilFestlegenRechteck(-50, 4, 72, 6, "blau");           
        FigurteilFestlegenRechteck(-38, 10, 6, 6, "blau");           
        FigurteilFestlegenRechteck(4, 10, 6, 6, "blau");     
 
        // Hände
        FigurteilFestlegenRechteck(-50, 10, 12, 18, "orange");        
        FigurteilFestlegenRechteck(-38, 16, 6, 6, "orange");                
        FigurteilFestlegenRechteck(10, 10, 12, 18, "orange");        
        FigurteilFestlegenRechteck(6, 16, 6, 6, "orange");                
 
        // braune Hose
        FigurteilFestlegenRechteck(-20, 10, 12, 14, "braun");   
        FigurteilFestlegenRechteck(-32, 10, 12, 24, "braun");   
        FigurteilFestlegenRechteck(-8, 10, 12, 24, "braun");   
        FigurteilFestlegenRechteck(-38, 22, 6, 12, "braun");   
        FigurteilFestlegenRechteck(4, 22, 6, 12, "braun");   
 
        // Schuhe
        FigurteilFestlegenRechteck(-44, 34, 18, 12, "grau");       
        FigurteilFestlegenRechteck(-50, 40, 6, 6, "grau");       
        FigurteilFestlegenRechteck(-2, 34, 18, 12, "grau");       
        FigurteilFestlegenRechteck(16, 40, 6, 6, "grau");
    }
}
