import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)

/**
 * Ein Fahrzeugsymbol
 *
 * @author Albert Wiedemann
 * @version 1.0
 */
class FahrzeugSymbol
{
    /** Länge des Fahrzeugs */
    int länge;
    /** Breite des Fahrzeugs */
    int breite;

    //Interna
    /** Farbe des Fahrzeugs */
    String aktFarbe;
    /** x-Position des Fahrzeugs */
    int x;
    /** y-Position des Fahrzeugs */
    int y;
    /** Fahrzeugaufbau */
    Rechteck aufbau;
    /** Frontscheibe */
    Rechteck scheibe;

    /**
     * Standardkonstruktor für Objekte der Klasse FahrzeugSymbol.
     */
    FahrzeugSymbol()
    {
        länge = 22;
        breite = 9;
        aktFarbe = "blau";
        aufbau = new Rechteck();
        aufbau.GrößeSetzen(breite, länge);
        aufbau.FarbeSetzen(aktFarbe);
        GrafikWelt.dieWelt.addObject(aufbau, -50, -50);
        aufbau.PositionSetzen(0, 0);
        scheibe = new Rechteck();
        scheibe.GrößeSetzen(breite - 2, länge/4);
        scheibe.FarbeSetzen("weiß");
        GrafikWelt.dieWelt.addObject(scheibe, -50, -50);
        scheibe.PositionSetzen(1, länge/4);
    }

    /**
     * Setzt die Farbe des Fahrzeugsymbols.
     * @param neueFarbe die neue Farbe des Fahrzeugsymbols
     */
    void FarbeSetzen(String neueFarbe)
    {
        aktFarbe = neueFarbe;
        aufbau.FarbeSetzen(aktFarbe);
    }

    /**
     * Setzt die Position des Fahrzeugsymbols.
     * Die Koordinaten bezeichnen die linke, obere Ecke des Fahrzeugsymbols.
     * @param x x-Position
     * @param y y-Position
     */
    void PositionSetzen(int x, int y)
    {
        this.x = x;
        this.y = y;
        aufbau.PositionSetzen(x, y);
        scheibe.PositionSetzen(x + 1, y + länge/4);
    }

    /**
     * Entfernt das Fahrzeugsymbol aus der Anzeige
     */
    void Entfernen()
    {
        aufbau.Entfernen();
        scheibe.Entfernen();
    }
}
