import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)

/**
 * Das Symbol des Schlangenrumpfs.
 * Das Fenster wird bei Bedarf generiert.
 *
 * @author Albert Wiedemann
 * @version 1.0
 */
class RumpfSymbol extends Actor
{
    /** x-Position */
    int x;
    /** y-Position */
    int y;

    /**
     * Standardkonstruktor für Objekte der Klasse RumpfSymbol.
     * Er erzeugt ein Kopfsymbol an Postion (0 | 0).
     */
    RumpfSymbol()
    {
        PositionSetzen(0, 0);
    }
    
    /**
     * Setzt die Position der Mitte des Symbols.
     * @param x x-Position der Mitte
     * @param y y-Position der Mitte
     */
    @Override public void setLocation(int x, int y)
    {
        this.x = x - 13;
        this.y = y - 10;
        super.setLocation(x, y);
    }
    
    /**
     * Setzt den Winkel konstant auf 0
     * @param winkel der (neue) Drehwinkel des Dreiecks
     */
    @Override public void setRotation(int w)
    {
        super.setRotation(0);
    }

    /**
     * Setzt die Position des Kopfelements.Der Ursprung liegt in der Mitte des
     * Fensters, die y-Achse zeigt nach unten.(x /y) bedeutet das
     * Kästchen rechts unterhalb der Gitterlinien.
     * @param x x-Position
     * @param y y-Position
     */
    void PositionSetzen(int x, int y)
    {
        this.x = x;
        this.y = y;
        super.setLocation(x + 13, y + 10);
    }

    /**
     * Gibt den X-Wert der Position des Kopfelements.
     * @return x-Position
     */
    int XPositionGeben()
    {
        return x;
    }

    /**
     * Gibt den Y-Wert der Position des Kopfelements.
     * @return y-Position
     */
    int YPositionGeben()
    {
        return y;
    }
    
    /**
     * Entfernt die Figur aus der Anzeige
     */
    void Entfernen()
    {
        getWorld().removeObject(this);
    }
}
